==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d2/da5/structGameCreationSettings.js <==
var structGameCreationSettings =
[
    [ "amount_of_rivers", "d2/da5/structGameCreationSettings.html#a7299c740563a2a9280a6d6922a79aedc", null ],
    [ "custom_sea_level", "d2/da5/structGameCreationSettings.html#a76c3a7bd3c5c1ab64442475aae087ae6", null ],
    [ "custom_town_number", "d2/da5/structGameCreationSettings.html#a96bb9b2cb5e429e8b43820af4b016805", null ],
    [ "generation_seed", "d2/da5/structGameCreationSettings.html#ad5dd48b3d15de9a52e7cdd810fb0f3c8", null ],
    [ "heightmap_rotation", "d2/da5/structGameCreationSettings.html#a9d83a54d4a36c88bf0212212f9069e01", null ],
    [ "land_generator", "d2/da5/structGameCreationSettings.html#a77197a159ebf070a3895660460965710", null ],
    [ "landscape", "d2/da5/structGameCreationSettings.html#a61b1817477a37fcdb7b37bfd5ba4f05e", null ],
    [ "map_x", "d2/da5/structGameCreationSettings.html#a6e791997bc000e870f0a2d1ad19c656e", null ],
    [ "map_y", "d2/da5/structGameCreationSettings.html#a7bf63ca43b4071b7be3564aab0fdbec8", null ],
    [ "min_river_length", "d2/da5/structGameCreationSettings.html#a54ab0e9d51e84aab23901340c5cd654c", null ],
    [ "oil_refinery_limit", "d2/da5/structGameCreationSettings.html#aa78c7c4ed4bf9d55832c3d3496d07a9c", null ],
    [ "river_route_random", "d2/da5/structGameCreationSettings.html#a1f55e505060d49cbe4674c537a0dbad5", null ],
    [ "se_flat_world_height", "d2/da5/structGameCreationSettings.html#a33671597de912f6c3fe393d3e5ec0950", null ],
    [ "snow_line_height", "d2/da5/structGameCreationSettings.html#a7788747fe39df24ca8e619c53f13db9b", null ],
    [ "starting_year", "d2/da5/structGameCreationSettings.html#a5d02f50a9c625d77417c4a96adc7148e", null ],
    [ "tgen_smoothness", "d2/da5/structGameCreationSettings.html#a1985a002d7687bd74bc42ff9d7b7a440", null ],
    [ "town_name", "d2/da5/structGameCreationSettings.html#af45cff786e5e58b0caee23c08360b9c9", null ],
    [ "tree_placer", "d2/da5/structGameCreationSettings.html#a08c926be04152b7ce5e3e8f0915f2e7f", null ],
    [ "variety", "d2/da5/structGameCreationSettings.html#a3e0c10fb5e62ca413f47486b0e9726d4", null ],
    [ "water_borders", "d2/da5/structGameCreationSettings.html#a91d892ddcf3257d63fc9cf26615df84c", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d2/da5/structGameCreationSettings.js <==
var structGameCreationSettings =
[
    [ "amount_of_rivers", "d2/da5/structGameCreationSettings.html#a7299c740563a2a9280a6d6922a79aedc", null ],
    [ "custom_sea_level", "d2/da5/structGameCreationSettings.html#a76c3a7bd3c5c1ab64442475aae087ae6", null ],
    [ "custom_town_number", "d2/da5/structGameCreationSettings.html#a96bb9b2cb5e429e8b43820af4b016805", null ],
    [ "ending_year", "d2/da5/structGameCreationSettings.html#aa3fec2bfdbcd6f3559acb9862ac3ff76", null ],
    [ "generation_seed", "d2/da5/structGameCreationSettings.html#ad5dd48b3d15de9a52e7cdd810fb0f3c8", null ],
    [ "heightmap_rotation", "d2/da5/structGameCreationSettings.html#a9d83a54d4a36c88bf0212212f9069e01", null ],
    [ "land_generator", "d2/da5/structGameCreationSettings.html#a77197a159ebf070a3895660460965710", null ],
    [ "landscape", "d2/da5/structGameCreationSettings.html#a61b1817477a37fcdb7b37bfd5ba4f05e", null ],
    [ "map_x", "d2/da5/structGameCreationSettings.html#a6e791997bc000e870f0a2d1ad19c656e", null ],
    [ "map_y", "d2/da5/structGameCreationSettings.html#a7bf63ca43b4071b7be3564aab0fdbec8", null ],
    [ "min_river_length", "d2/da5/structGameCreationSettings.html#a54ab0e9d51e84aab23901340c5cd654c", null ],
    [ "oil_refinery_limit", "d2/da5/structGameCreationSettings.html#aa78c7c4ed4bf9d55832c3d3496d07a9c", null ],
    [ "river_route_random", "d2/da5/structGameCreationSettings.html#a1f55e505060d49cbe4674c537a0dbad5", null ],
    [ "se_flat_world_height", "d2/da5/structGameCreationSettings.html#a33671597de912f6c3fe393d3e5ec0950", null ],
    [ "snow_line_height", "d2/da5/structGameCreationSettings.html#a7788747fe39df24ca8e619c53f13db9b", null ],
    [ "starting_year", "d2/da5/structGameCreationSettings.html#a5d02f50a9c625d77417c4a96adc7148e", null ],
    [ "tgen_smoothness", "d2/da5/structGameCreationSettings.html#a1985a002d7687bd74bc42ff9d7b7a440", null ],
    [ "town_name", "d2/da5/structGameCreationSettings.html#af45cff786e5e58b0caee23c08360b9c9", null ],
    [ "tree_placer", "d2/da5/structGameCreationSettings.html#a08c926be04152b7ce5e3e8f0915f2e7f", null ],
    [ "variety", "d2/da5/structGameCreationSettings.html#a3e0c10fb5e62ca413f47486b0e9726d4", null ],
    [ "water_borders", "d2/da5/structGameCreationSettings.html#a91d892ddcf3257d63fc9cf26615df84c", null ]
];
